/*
 * This file is a part of KEMET project (Library).
 * 
 * Copyright (C) 2008 MAUPIN Fabrice
 *
 * This library is free software; 
 * you can redistribute it and/or modify it under the terms of the GNU Lesser General Public License 
 * as published by the Free Software Foundation; 
 * either version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; 
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. 
 * See the GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License along with this library; 
 * if not, write to the Free Software Foundation, 
 * Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA 
 */
package org.kemet.tests.phonograms;

import org.apache.log4j.Logger;
import org.junit.Test;
import org.kemet.tests.TestRoot;

/**
 * 
 * @author fabricemaupin
 * 
 * <p>
 * <b>fonctionnal tests for uniliteral.</b>
 * </p>
 * 
 * @since 0.1
 * 
 */
public class TestUniliteral extends TestRoot {
	static final Logger log = Logger.getLogger("org.kemet.tests");

	/**
	 * <p>
	 * <b>list of signs.</b>
	 * </p>
	 */
	private String[] signList;

	/**
	 * <p>
	 * <b>list of transliterated sequence.</b>
	 * </p>
	 */
	private String[] transliterationList;

	/**
	 * <p>
	 * <b>list of transliterated sequence 2.</b>
	 * </p>
	 */
	private String[] transliterationList2;

	/**
	 * <p>
	 * <b>expected result.</b>
	 * </p>
	 */
	private String resultsM1T1;

	/**
	 * <p>
	 * <b>expected result 2.</b>
	 * </p>
	 */
	private String resultsM1T2;

	/**
	 * <p>
	 * <b>expected result 3.</b>
	 * </p>
	 */
	private String resultsM1T3;

	/**
	 * <p>
	 * <b>expected result 4.</b>
	 * </p>
	 */
	private String resultsM1T3b;

	/**
	 * <p>
	 * <b>set the parameters before execute the tests.</b>
	 * </p>
	 * 
	 * @since 0.1
	 */
	public void init() {
		// initialize the data tests...
		signList = new String[] { "G1_N29_G370", "M17_O34_I9_X1_G370",
				"G43_D58_N35_N80", "I9_N29_G1_Z80_Y10", "G17_S29_V28_I30",
				"O4_D21_G43_N50", "F32_V31_D21_Aa300", "S29_D58_V28_F180_A20",
				"W11_D21_V28_N200", "D46_G1_M17_Z7_Y50" };

		resultsM1T1 = "3q?jsft?wbn?fq3??msh.?hrw?h_kr?sbh.?grh.?d3jw?";

		transliterationList = new String[] { "jqr", "psh.", "rd" };

		resultsM1T2 = "M17N29D21Q3[O34;S29]V28D21D46";
		resultsM1T3 = "ikrps (sourd)h (aspiré)rd";

		transliterationList2 = new String[] { "s", "3tp", "bjn", "ws^b",
				"h.nc", "stp", "dbh.", "sd_m", "dpt", "dbn", "ds" };

		resultsM1T3b = "s (sourd)éatèpbineouchèbh (aspiré)énas (sourd)étèpdébéh (aspiré)s (sourd)édjèmdépètdébèndès (sourd)";

		// get the uniliteres phonograms
		org.kemet.impl.grammar.model.Phonogram.getPhonogramsByType(UNILITERAL);
	}

	/**
	 * <p>
	 * <b>test : verify if the format of the transliteration is correct +
	 * hieroglyphs to transliteration.</b>
	 * </p>
	 * 
	 * @since 0.1
	 */
	@Test
	public void testUnEx1() {
		// test when we have that ???
		try {
			assertEquals(gm.toTransliteration(new String[] { "???" }, 0), "?");
		} catch (Exception e) {
			assertTrue(false);
		}

		// test if you have the good transliteration
		try {
			assertEquals(gm.toTransliteration(signList, 0), resultsM1T1);
		} catch (Exception e) {
			assertTrue(false);
		}

		/*
		 * test if the returned transliterate string is with the good format
		 * (exclude (y/n) "?" caracter)
		 */
		try {
			assertEquals(gm.isTCorrectFormat(gm.toTransliteration(signList, 0),
					true), true);
		} catch (Exception e) {
			assertTrue(false);
		}

		try {
			assertEquals(gm.isTCorrectFormat(gm.toTransliteration(signList, 0),
					false), false);
		} catch (Exception e) {
			assertTrue(false);
		}

		assertEquals(gm.isTCorrectFormat(
				"3x?jsft?wbn?fq3??msh.?hrw?h_kr?sbh.??grh.?d3jw?", true), false);
	}

	/**
	 * <p>
	 * <b>test : transliteration to hieroglyphs.</b>
	 * </p>
	 * 
	 * @since 0.1
	 */
	@Test
	public void testUnEx2() {
		// test if the returned signs are correct
		try {
			assertEquals(gm.toHieroglyphs(transliterationList), resultsM1T2);
		} catch (Exception e) {
			assertTrue(false);
		}

		// test if the transliteration is not correct
		try {
			assertEquals(gm.toHieroglyphs(new String[] { "???" }), "");
		} catch (Exception e) {
			assertTrue(false);
		}

		try {
			assertEquals(gm.toHieroglyphs(new String[] { "" }), "");
		} catch (Exception e) {
			assertTrue(false);
		}

		try {
			assertEquals(gm.toHieroglyphs(new String[] { "jer" }), "M17D21");
		} catch (Exception e) {
			assertTrue(false);
		}

		try {
			assertEquals(gm.toHieroglyphs(new String[] { "j.r" }), "M17D21");
		} catch (Exception e) {
			assertTrue(false);
		}

		try {
			assertEquals(gm.toHieroglyphs(new String[] { "?jer" }), "M17D21");
		} catch (Exception e) {
			assertTrue(false);
		}
	}

	/**
	 * <p>
	 * <b>test : phonetic read.</b>
	 * </p>
	 * 
	 * @since 0.1
	 */
	@Test
	public void testUnp3() {
		// test if the returned phonetic read is correct
		try {
			assertEquals(gm.toPhoneticRead(transliterationList, false),
					resultsM1T3);
		} catch (Exception e) {
			assertTrue(false);
		}

		// test if the complete returned phonetic read is correct
		try {
			assertEquals(gm.toPhoneticRead(transliterationList2, true),
					resultsM1T3b);
		} catch (Exception e) {
			assertTrue(false);
		}
	}
}
